pick_sketch

Function pick_sketch 

pub fn pick_sketch<S: Scalar>(
    targets: &SketchTargets<S>,
    ray: Ray<S>,
    tolerance: f64,
) -> Option<SketchHit<S>>
The sketch nearest along ray that it hits (see [hit_sketch]), with tolerance the world-space distance within which a click counts as on a curve.